@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-
 from sqlalchemy import MetaData
-import six
 
 from ..db import db
 
@@ -20,10 +17,20 @@ class DialectOperations(object):
         if not self.option_defaults:
             return
         for option_key in self.option_defaults.keys():
-            full_key = '{}.{}'.format(self.dialect_name, option_key)
+            # Each option will be determined from the most specific config key set for
+            # the dialect and bind:
+            # bind-level dialect option > generic dialect option > default value
+            dialect_key = '{}.{}'.format(self.dialect_name, option_key)
+            bind_key = 'bind.{}.{}'.format(self.bind_name, option_key)
             attr_name = 'opt_{}'.format(option_key)
             default_opt_value = self.option_defaults[option_key]
-            opt_value = option_pairs.get(full_key, default_opt_value)
+            opt_value = option_pairs.get(
+                bind_key,
+                option_pairs.get(
+                    dialect_key,
+                    default_opt_value
+                )
+            )
             setattr(self, attr_name, opt_value)
 
     def execute_sql(self, statements):
@@ -32,7 +39,7 @@ class DialectOperations(object):
 
     def create_all(self):
         self.create_schemas()
-        db.create_all(bind=self.bind_name)
+        db.create_all(self.bind_name)
 
     def create_schemas(self):
         pass
@@ -128,7 +135,7 @@ class MicrosoftSQLOps(DialectOperations):
             'U': 'drop table [{schema_name}].[{name}]',
         }
         delete_sql = []
-        for type, drop_sql in six.iteritems(mapping):
+        for type, drop_sql in mapping.items():
             sql = 'select name, object_name( parent_object_id ) as parent_name '\
                 ', OBJECT_SCHEMA_NAME(object_id) as schema_name '\
                 'from sys.objects where type in (\'{}\')'.format("', '".join(type))
