@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-from unittest import mock
-
 import pytest
 
 from keg import current_app
@@ -35,21 +32,21 @@ class TestDB(object):
         # the component has loaded properly
         from keg_apps.db.blog.model.entities import Blog
         assert Blog.query.count() == 0
-        blog = Blog(title=u'foo')
+        blog = Blog(title='foo')
         db.session.add(blog)
         db.session.commit()
         assert Blog.query.count() == 1
 
     def test_postgres_bind_db_entity(self):
         assert ents.PGDud.query.count() == 0
-        dud = ents.PGDud(name=u'foo')
+        dud = ents.PGDud(name='foo')
         db.session.add(dud)
         db.session.commit()
         assert ents.PGDud.query.count() == 1
 
     def test_postgres_db_enttity_alt_schema(self):
         assert ents.PGDud2.query.count() == 0
-        dud = ents.PGDud2(name=u'foo')
+        dud = ents.PGDud2(name='foo')
         db.session.add(dud)
         db.session.commit()
         assert ents.PGDud2.query.count() == 1
@@ -61,7 +58,10 @@ class TestDB2(object):
         # Make sure we don't get an error initializing the app when the SQLALCHEMY_BINDS config
         # option is None
         app = DB2App.testing_prep()
-        assert app.config.get('SQLALCHEMY_BINDS') is None
+        value = app.config.get('SQLALCHEMY_BINDS')
+        # flask-sqlalchemy < 3.0: None
+        # flask-sqlalchemy 3.0+: {}
+        assert value is None or value == {}
 
 
 class TestDatabaseManager(object):
@@ -115,23 +115,6 @@ class TestDatabaseManager(object):
         assert self.clear_pre_connected
         assert self.clear_post_connected
 
-    def test_prep_empty_deprecation(self):
-        current_app.db_manager.prep_empty = lambda *args, **kwargs: False
-
-        try:
-            with mock.patch('keg.db.warnings.warn', autospec=True, spec_set=True) as m_warn:
-                current_app.db_manager.db_init_with_clear()
-                m_warn.assert_called_once_with(
-                    'prep_empty is deprecated and will not be called in future versions',
-                    DeprecationWarning, 2)
-
-                m_warn.reset_mock()
-                current_app.db_manager.prep_empty = None
-                current_app.db_manager.db_init_with_clear()
-                assert not m_warn.call_count
-        finally:
-            del current_app.db_manager.prep_empty
-
 
 class TestKegSQLAlchemy(object):
     def test_session_ids_with_cli_invocation(self):
